@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2017 Mirai Solutions GmbH
+# Copyright (C) 2010-2018 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ setGeneric("setStyleNamePrefix",
 setMethod("setStyleNamePrefix", 
 		signature(object = "workbook"), 
 		function(object, prefix) {
-			jTryCatch(object@jobj$setStyleNamePrefix(prefix))
+		  xlcCall(object, "setStyleNamePrefix", prefix, .recycle = FALSE)
+		  invisible()
 		}
 )
